import javax.jms.*;
import javax.naming.*;
import java.io.*;
import java.util.*;

// This is an example JMS message recipient program that receives simple
// message objects from the queue using the Point to Point mode communication.
// The messages received by the recipient are sent by the JmsMsgSender.java program. 

public class JmsMsgRecipient {
    QueueConnection 	queueConn;
    QueueSession 		queueSession;
    QueueReceiver 		queueRecipient;
    QueueConnectionFactory	queueConnFactory;
    Queue 				queue;
    Context 			jndiContext;
    TextMessage 		txtMessage;
    ObjectMessage		objMessage; 
    String 				msgQueueName;

    JmsMsgRecipient(String queueName) {
        try {
	    // set the message queue name obtained from command prompt arguments
            msgQueueName = new String(queueName);
	    // create initial JNDI context 
            jndiContext = new InitialContext();

	    // obtain the queue connection factory for the queueu from the initial JNDI context
            queueConnFactory = (QueueConnectionFactory)
                jndiContext.lookup("QueueConnectionFactory");

	    // obtain the queue from the initial JNDI context
            queue = (Queue) jndiContext.lookup(msgQueueName);

	    // from the queue connection factory create a queue connection object and then
	    // create a queue session object.
            queueConn = queueConnFactory.createQueueConnection();
            queueSession = queueConn.createQueueSession(false, 
                    Session.AUTO_ACKNOWLEDGE);

	    // the queue sender object is used to send messages to the queue
            queueRecipient = queueSession.createReceiver(queue);
	    queueConn.start();
	
	    // create a text message and object message for the session
            txtMessage = queueSession.createTextMessage();
	    objMessage = queueSession.createObjectMessage();
	    Calendar currTime = null;

            while (true) {
                Message msg = queueRecipient.receiveNoWait();
                if (msg != null) {
                    if (msg instanceof TextMessage) {
			// retrieve the text message and display
                        txtMessage = (TextMessage) msg;
                        System.out.println("First message received : " + txtMessage.getText());
                    } 
		    else if (msg instanceof ObjectMessage) {
			objMessage = (ObjectMessage) msg;
                        currTime = (Calendar)objMessage.getObject();
                        System.out.println("Second message received : " + currTime.getTime().toString());
                    }
		    else {
			break;
		    }
                }
            }

        } 
	catch (NamingException ne) {
            System.out.println("Error while creating/accessing JNDI Initial Context " +
                "Context : " + ne.toString());
            System.exit(-1);
        }
        catch (JMSException je) {
            System.out.println("JMSException occurred while receiving a message " + 
                je.toString());
	}
	catch (Exception ex) {
            System.out.println("Error occured while running the message recipient program");
	    ex.printStackTrace();
            System.exit(-1);
        }
    }

    public static void main(String[] args) {
        try {
	    // make sure that the queue name is provided in the command line argument
            if (args.length != 1) {
		throw new Exception("Queue name (one word) should be specified at command prompt");
            }
	}
	catch (Exception ex) {
            System.out.println("Error occured while running the message recipient program");
	    ex.printStackTrace();
            System.exit(-1);
        }
	JmsMsgRecipient msgRecipient = new JmsMsgRecipient(args[0]);
    }
}
