import javax.jms.*;
import javax.naming.*;
import java.io.*;
import java.util.*;

// This is an example JMS message sender program that sends simple
// message objects using the Point to Point mode communication.
// The program first sends a name and then a calendar object with
// current time. The recipient should receive them in the same order.

public class JmsMsgSender {
    QueueConnection 	queueConn;
    QueueSession 		queueSession;
    QueueSender  		queueSender;
    QueueConnectionFactory	queueConnFactory;
    Queue 				queue;
    Context 			jndiContext;
    TextMessage 		txtMessage;
    ObjectMessage		objMessage; 
    String 				msgQueueName;
    String				myName;

    JmsMsgSender(String queueName, String helloName) {
        try {
	    // set the message queue name obtained from command prompt arguments
            msgQueueName = new String(queueName);
	    myName = new String(helloName);
	    // create initial JNDI context 
            jndiContext = new InitialContext();

	    // obtain the queue connection factory for the queueu from the initial JNDI context
            queueConnFactory = (QueueConnectionFactory)
                jndiContext.lookup("QueueConnectionFactory");

	    // obtain the queue from the initial JNDI context
            queue = (Queue) jndiContext.lookup(msgQueueName);

	    // from the queue connection factory create a queue connection object and then
	    // create a queue session object.
            queueConn = queueConnFactory.createQueueConnection();
            queueSession = queueConn.createQueueSession(false, 
                    Session.AUTO_ACKNOWLEDGE);

	    // the queue sender object is used to send messages to the queue
            queueSender = queueSession.createSender(queue);
	
	    // create a text message and object message for the session
            txtMessage = queueSession.createTextMessage();
	    objMessage = queueSession.createObjectMessage();

	    // send myName as the first message
	    txtMessage.setText(myName);
	    queueSender.send(txtMessage);
	    System.out.println("Sent '" + myName + "' as first message");

	    // send a calendar object with current timestamp as the second message
	    Calendar currTime = Calendar.getInstance();
	    objMessage.setObject(currTime);
	    queueSender.send(objMessage);
	    System.out.println("Sent current time '"+ currTime.getTime().toString()+ "' as second message");

        } 
	catch (NamingException ne) {
            System.out.println("Error while creating/accessing JNDI Initial Context " +
                "Context : " + ne.toString());
            System.exit(-1);
        }
        catch (JMSException je) {
            System.out.println("JMSException occurred while sending a message " + 
                je.toString());
	}
	catch (Exception ex) {
            System.out.println("Error occured while running the message sender program");
	    ex.printStackTrace();
            System.exit(-1);
        }
    }

    public static void main(String[] args) {
        try {
	    // make sure that the queue name is provided in the command line argument
            if (args.length != 2) {
		throw new Exception("Queue name (one word) and your name (one word) should be specified at command prompt");
            }
	}
	catch (Exception ex) {
            System.out.println("Error occured while running the message sender program");
	    ex.printStackTrace();
            System.exit(-1);
        }
	JmsMsgSender msgSender = new JmsMsgSender(args[0], args[1]);
    }
}
